<script>
import {MasterMethods} from "@/Store/Functions.js";
import {useForm} from "@inertiajs/vue3";
import Toast from "@/Componentes/Toastify/Toast.vue";
import {ref} from 'vue';

export default {
    name: "Subscription",
    components: {Toast},
    props: ["customer","currentPage"],
    emits: ["closeModal"],
    created() {
        this.vip.count = 1;
        this.$page.props.customer = null;
        this.user = this.customer;
        this.resetForm(this.vip);
    },
    data(){
        return {
            period: "dias",
            user: this.customer,
            vip: useForm({
                id: this.user?.id,
                role_id: this.user?.role_id,
                vip_end_date: this.user?.vip_end_date,
                period: "dias",
                count: 0,
                page: this.currentPage
            }),
        }
    },
    methods: {
        ...MasterMethods,
        submit(){
            this.vip.id =this.user?.id;
            this.vip.role_id = this.user?.role_id;
            this.vip.vip_end_date = this.user?.vip_end_date;
            this.resetForm(this.vip)
            this.vip.put(route("users.update"),{
                preserveScroll: true,
                onSuccess: () => {
                    this.vip.reset();
                    this.user = {};
                    this.$emit("closeModal")
                }
            })
        }
    },
    watch:{
        period(value){
            this.vip.period = value;
        },
        "$page.props.customer": {
            immediate: true,
            handler(newValue){
                if(newValue){
                    this.user = newValue;
                }
            }
        }
    }
}
</script>
<template>
    <Toast :response="vip" />
    <div class="card card-widget widget-user-2 shadow-sm">
        <div class="widget-user-header bg-gray-800">
            <div class="widget-user-image">
                <img class="img-circle elevation-2" :src="user?.profile_photo_url" alt="User Avatar">
            </div>
            <!-- /.widget-user-image -->
            <h3 class="widget-user-username text-white">{{ user?.name }}</h3>
            <h5 class="widget-user-desc text-white">Membresia: <span class="font-bold">{{ user?.role?.name}}</span></h5>
        </div>
        <div class="card-body p-0">
            <ul class="nav flex-column">
                <li class="nav-item">
                    <a href="#" class="nav-link">
                        Inicio de Membresia <span class="float-right badge">{{ user?.vip_start_date }}</span>
                    </a>
                </li>
                <li class="nav-item">
                    <a href="#" class="nav-link">
                        Fin de Membresia <span class="float-right badge">{{ user?.vip_end_date }}</span>
                    </a>
                </li>
            </ul>
        </div>
        <div class="card-footer border-t">
            <div class="alert alert-info py-1 text-xs">
                Ingresa el numero de dias o meses para agregar la suscripcion del usuario.
            </div>

            <form v-on:submit.prevent="submit">
                <div class="input-group mb-3">
                    <div @click="period='dias'" class="input-group-prepend cursor-pointer">
                        <span :class="{active: period === 'dias'}" class="input-group-text rounded-none hover-period">Dia</span>
                    </div>
                    <div @click="period='meses'" class="input-group-prepend cursor-pointer">
                        <span :class="{active: period === 'meses'}" class="input-group-text hover-period">Mes</span>
                    </div>
                    <input :max="period === 'meses'?12:365" type="number" v-model="vip.count" required min="1" class="form-control border-gray-300" :placeholder="'Numero de ' + period">
                    <div class="input-group-prepend">
                        <button type="submit" class="btn bg-gray-900 hover:bg-gray-800 text-white">Agregar</button>
                    </div>
                    <div class="input-group-prepend">
                        <button @click="$emit('closeModal')" type="button" class="btn bg-red-700 hover:bg-red-600 text-white">Cerrar</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</template>

<style scoped>
.hover-period{
    @apply hover:bg-gray-600 hover:text-white hover:border-gray-700
}
.hover-period.active{
    @apply bg-gray-800 text-white border-gray-900
}
</style>
